| Title: | Manage Person and Organisation Information |
|---|---|
| Description: | Manage person and organisation information with validation and formatting capabilities. Provides R6 classes for managing organisations and their members, with support for multiple languages, ORCID identifiers, ROR identifiers, licensing requirements, publisher information, and integration with citation management systems. |
| Authors: | Thierry Onkelinx [aut, cre] (ORCID: <https://orcid.org/0000-0001-8804-4216>, affiliation: Research Institute for Nature and Forest (INBO)), Research Institute for Nature and Forest (INBO) [cph, fnd, pbl] (ROR: <https://ror.org/00j54wy13>) |
| Maintainer: | Thierry Onkelinx <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-06-07 06:25:29 UTC |
| Source: | https://github.com/inbo/citeme |
doi: add a DOI badge
language: add a language badge
license: add a license badge
url: add a website badge
version: add a version badge
add_badges(readme_path = ".", ...)add_badges(readme_path = ".", ...)
readme_path |
Directory containing the |
... |
Additional arguments |
Other utils:
coalesce()
## Not run: add_badges(url = "https://www.inbo.be") add_badges(doi = "10.5281/zenodo.8063503") add_badges(version = "v0.1.2") add_badges(url = "https://www.inbo.be", doi = "10.5281/zenodo.8063503") ## End(Not run)## Not run: add_badges(url = "https://www.inbo.be") add_badges(doi = "10.5281/zenodo.8063503") add_badges(version = "v0.1.2") add_badges(url = "https://www.inbo.be", doi = "10.5281/zenodo.8063503") ## End(Not run)
Add an individual to a file
add_individual( path = ".", role = c("aut", "cre", "ctb", "rev", "cph", "fnd", "pbl") )add_individual( path = ".", role = c("aut", "cre", "ctb", "rev", "cph", "fnd", "pbl") )
path |
A path to a file or directory. Supported file types:
|
role |
The role of the person to add.
One or multiple of |
Other individual:
has_person_role(),
individual2badge(),
individual2df(),
individual2person(),
select_individual(),
select_person_role(),
store_individuals()
Ask for an e-mail address
ask_email(prompt)ask_email(prompt)
prompt |
the string printed when prompting the user for input.
Should usually end with a space |
Other question:
ask_language(),
ask_new_license(),
ask_orcid(),
ask_ror(),
ask_url(),
ask_yes_no(),
menu_first()
Ask for a language
ask_language(org, prompt = "Which language?")ask_language(org, prompt = "Which language?")
org |
An |
prompt |
the string printed when prompting the user for input.
Should usually end with a space |
Other question:
ask_email(),
ask_new_license(),
ask_orcid(),
ask_ror(),
ask_url(),
ask_yes_no(),
menu_first()
Ask one or more licenses.
ask_new_license(licenses, type = c("package", "project", "data"))ask_new_license(licenses, type = c("package", "project", "data"))
licenses |
A named vector of available licenses. The vector contains the URL to the markdown version of the license. Use the abbreviation of the license name as names. |
type |
The type of license.
Must be one of |
Other question:
ask_email(),
ask_language(),
ask_orcid(),
ask_ror(),
ask_url(),
ask_yes_no(),
menu_first()
ORCID iD
The ORCID iD is a unique, persistent identifier
free of charge to researchers.
This function prompts the user to enter an ORCID iD and validates its
format.
The ORCID iD must be in the format 0000-0000-0000-0000 where the last
digit can be a number or "X".
Empty strings are considered valid to allow optional ORCID iD.
ask_orcid(prompt = "orcid: ")ask_orcid(prompt = "orcid: ")
prompt |
A character string to display as a prompt to the user.
The default is |
A character string containing the ORCID iD entered by the user.
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_ror(),
ask_url(),
ask_yes_no(),
menu_first()
The Research Organization Registry (ROR) is a global, community-led registry of open persistent identifiers for research organizations. ROR makes it easy for anyone or any system to disambiguate institution names and connect research organizations to researchers and research outputs.
ask_ror(prompt)ask_ror(prompt)
prompt |
the string printed when prompting the user for input.
Should usually end with a space |
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_orcid(),
ask_url(),
ask_yes_no(),
menu_first()
Ask an URL
ask_url(prompt)ask_url(prompt)
prompt |
the string printed when prompting the user for input.
Should usually end with a space |
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_orcid(),
ask_ror(),
ask_yes_no(),
menu_first()
Provides a simple wrapper around utils::askYesNo().
This function is used to ask yes no questions in an interactive way.
It repeats the question until a valid answer is given.
ask_yes_no(msg, default = TRUE, prompts = c("Yes", "No", "Cancel"), ...)ask_yes_no(msg, default = TRUE, prompts = c("Yes", "No", "Cancel"), ...)
msg |
The prompt message for the user. |
default |
The default response. |
prompts |
Any of: a character vector containing 3 prompts corresponding to
return values of |
... |
Additional parameters, ignored by the default function. |
Other question:
ask_email(),
ask_language(),
ask_new_license(),
ask_orcid(),
ask_ror(),
ask_url(),
menu_first()
This function retrieves the organisation list from a given URL and caches it
locally.
If the URL is "https://github.com/inbo", it uses the default INBO
organisation list.
For other URLs, it checks if a public citeme repository exists and clones
it to retrieve the organisation list.
The cached organisation list is stored in a specified configuration folder.
cache_org(url, config_folder = R_user_dir("citeme", "config"))cache_org(url, config_folder = R_user_dir("citeme", "config"))
url |
The URL of the organisation list to retrieve. |
config_folder |
The folder where the cached organisation list should be
stored.
Defaults to the user's R configuration directory for |
The retrieved organisation list, or NULL if the URL is invalid or
the repository.
Other organisation:
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
organisation2df(),
select_license(),
store_organisations(),
stored_organisations()
citation_meta R6 classA class which contains citation information.
get_errorsReturn the errors
get_metaReturn the meta data as a list
get_notesReturn the notes
get_personReturn the individuals and organisations as a list of
person objects.
get_typeA string indicating the type of source.
get_pathThe path to the project.
get_warningsReturn the warnings
citation_meta$new()Initialize a new citation_meta object.
citation_meta$new(path = ".")
pathThe path to the root of the project or the file from which to extract citation metadata.
citation_meta$print()Print the citation_meta object.
citation_meta$print(...)
...currently ignored.
citation_meta$clone()The objects of this class are cloneable with this method.
citation_meta$clone(deep = FALSE)
deepWhether to make a deep clone.
Other class:
org_item,
org_list
Return the first non-NULL argument.
coalesce(...)coalesce(...)
... |
Arguments to check for non-NULL values. |
The first non-NULL argument, or NULL if all arguments are NULL.
Other utils:
add_badges()
This function retrieves the list of available organisations from the local configuration files and locally stored organisations. It returns a list containing the names, languages, licenses, ORCID, Zenodo, ROR, website, and logo of the available organisations.
get_available_organisations()get_available_organisations()
A list containing the names, languages, licenses, ORCID, Zenodo, ROR, website, and logo of the available organisations.
Other organisation:
cache_org(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
organisation2df(),
select_license(),
store_organisations(),
stored_organisations()
This function retrieves the default organisation list from the
organisation.yml file in the organisations citeme repository.
The origin of the repository is used to determine the root URL of the
organisation.
get_default_org_list(x = ".")get_default_org_list(x = ".")
x |
The path to the repository. Defaults to the current working directory. |
An org_list object containing the organisation list.
The function also stores the information in the user's R configuration.
Other organisation:
cache_org(),
get_available_organisations(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
organisation2df(),
select_license(),
store_organisations(),
stored_organisations()
Does a person object has a given role?
has_person_role(individual, role)has_person_role(individual, role)
individual |
A |
role |
A character vector of roles to check for. |
A logical vector indicating whether the individual has any of the specified roles.
Other individual:
add_individual(),
individual2badge(),
individual2df(),
individual2person(),
select_individual(),
select_person_role(),
store_individuals()
The INBO organisation list
inbo_org_list()inbo_org_list()
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
organisation2df(),
select_license(),
store_organisations(),
stored_organisations()
This function creates a markdown badge for an individual, including their name, ORCID, email, and affiliation if available. It also adds a footnote with the individual's role and affiliation.
individual2badge( individual, role = c("aut", "cre", "cph", "ctb", "fnd", "rev") )individual2badge( individual, role = c("aut", "cre", "cph", "ctb", "fnd", "rev") )
individual |
A data frame with columns |
role |
A character string indicating the individual's role.
Must be one or more of |
A character string containing the markdown badge for the individual.
Other individual:
add_individual(),
has_person_role(),
individual2df(),
individual2person(),
select_individual(),
select_person_role(),
store_individuals()
Results in a data.frame with the given name, family name, e-mail, ORCID,
affiliation and role.
Missing elements result in an empty string ("").
Persons with multiple roles will have the roles as a comma separated string.
individual2df(person)individual2df(person)
person |
The person object or a list of person objects, |
Other individual:
add_individual(),
has_person_role(),
individual2badge(),
individual2person(),
select_individual(),
select_person_role(),
store_individuals()
person objectThis function retrieves the individual information using
select_individual() and converts it to a person object.
If the individual argument is not provided, it will prompt the user to
select an individual.
The person object will include the given name, family name, email, ORCID,
and affiliation (if available) of the selected individual.
individual2person(individual, role = "aut", lang)individual2person(individual, role = "aut", lang)
individual |
An optional |
role |
The role to use for the |
lang |
The language to use for the affiliation. |
Other individual:
add_individual(),
has_person_role(),
individual2badge(),
individual2df(),
select_individual(),
select_person_role(),
store_individuals()
The path arguments specifies the directory at which to start the search for a git repository. If it is not a git repository itself, then its parent directory is consulted, then the parent's parent, and so on.
is_repository(path = ".")is_repository(path = ".")
path |
the location of the git repository, see details. |
TRUE if directory is in a git repository else FALSE
Other git:
is_tracked_not_modified(),
ssh_http()
Check if a file is tracked and not modified
is_tracked_not_modified(file, repo = ".")is_tracked_not_modified(file, repo = ".")
file |
path relative to the git root directory. |
repo |
path to the repository |
Other git:
is_repository(),
ssh_http()
This function creates a data frame that maps local license file names to
their corresponding remote license URLs.
The local file names are generated by converting the license names to
lowercase, replacing spaces and hyphens with underscores, and appending the
.md extension.
The remote file URLs are taken directly from the input license vector.
license_local_remote(license)license_local_remote(license)
license |
A named character vector where the names are the license names and the values are the corresponding remote license URLs. |
A data frame with two columns: local_file and remote_file.
The local_file column contains the generated local file names,
and the remote_file column contains the corresponding remote license URLs.
org_item
Interactively create a new org_item
new_org_item(languages, licenses)new_org_item(languages, licenses)
languages |
A character vector of language codes. |
licenses |
A list of license items. |
An org_item object.
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_list(),
org_list_from_url(),
organisation2df(),
select_license(),
store_organisations(),
stored_organisations()
An interactive alternative for org_list$new().
Reuses available organisations where possible.
new_org_list(git)new_org_list(git)
git |
An optional string with the absolute path to a git
organisation.
E.g. |
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
org_list_from_url(),
organisation2df(),
select_license(),
store_organisations(),
stored_organisations()
org_item R6 classA class containing a single organisation
as_listThe organisation as a list.
get_zenodoThe organisation Zenodo community.
get_default_nameThe organisation default name.
get_emailThe organisation email.
get_funderThe funder rules.
get_publisherThe publisher rules.
get_nameThe organisation names.
get_orcidThe ORCID rules.
get_rightsholderThe rightsholder rules.
org_item$new()Initialize a new org_item object.
org_item$new(
name,
email,
orcid = FALSE,
rightsholder = c("optional", "single", "shared", "when no other"),
funder = c("optional", "single", "shared", "when no other"),
publisher = c("optional", "single", "shared", "when no other"),
license = list(package = c(`GPL-3.0` =
paste("https://raw.githubusercontent.com/inbo/citeme/refs/heads/main",
"inst/licenses/gplv3.md", sep = "/"), MIT =
paste("https://raw.githubusercontent.com/inbo/citeme/refs/heads/main",
"inst/licenses/mit.md", sep = "/")), project = c(`CC BY 4.0` =
paste("https://raw.githubusercontent.com/inbo/citeme/refs/heads/main",
"inst/licenses/cc_by_4_0.md", sep = "/")), data = c(CC0 =
paste("https://raw.githubusercontent.com/inbo/citeme/refs/heads/main",
"inst/licenses/cc0.md",
sep = "/"))),
ror = "",
zenodo = "",
website = "",
logo = ""
)
nameA named vector with the organisation names in one or more languages. The first item in the vector is the default language. The names of the vector must match the language code.
emailAn email address for the organisation. Used to contact the organisation. And used to detect if a person is affiliated with the organisation.
orcidWhether the organisation requires an ORCID for every person that uses this organisation as affiliation.
rightsholderThe required copyright holder status for the
organisation.
"optional" means that the organisation is not required as the copyright
holder.
"single" means that the organisation must be the only copyright holder.
"shared" means that the organisation must be one of the copyright
holders.
"when no other" means that if no other copyright holder is specified,
the organisation must be the copyright holder.
funderThe required funder status for the organisation.
The categories are the same as for rightsholder.
publisherThe required publisher status for the organisation.
The categories are the same as for rightsholder.
licenseA list with the allowed licenses by the organisation.
The list may contain the following items:
package, project, and data.
Every item must be a named character vector with the allowed licenses.
The names must match the license name.
The values must either match the path to a license template in the
checklist package or an absolute URL to publicly available markdown
file with the license text.
Use character(0) to indicate that the organisation does not
require a specific license for that item.
package defaults to c("GPL-3.0", "MIT").
project defaults to "CC BY 4.0".
data defaults to "CC0 1.0".
rorThe optional ROR ID of the organisation.
zenodoThe optional Zenodo community ID of the organisation.
websiteThe optional website URL of the organisation.
logoThe optional logo URL of the organisation.
org_item$as_person()as_person The organisation as a person.
org_item$as_person(
lang = names(private$name)[1],
role = c("cph", "fnd", "pbl")
)
langThe language to use for the organisation name.
Defaults to the first language in the name vector.
roleThe role of the person in the organisation.
org_item$compare_by_name()Compares the number of matching words with the organisation
name.
Either Inf when there is a perfect match.
Otherwise a number between 0 and 1 indicating the ratio of the matching
words with the total number of words in name.
A value of 1 means that all words in name are present in one of the
organisation names but in a different order.
org_item$compare_by_name(name)
nameThe name to match.
org_item$get_license()Get the organisation license.
org_item$get_license(type = c("package", "project", "data", "all"))
typeThe type of license to get.
Can be one of "package", "project", or "data".
Defaults to "package".
A named character vector with the allowed licenses.
org_item$get_pkgdown()The pkgdown author field.
org_item$get_pkgdown(lang)
langThe language to use for the organisation name.
org_item$print()Print the org_item object.
org_item$print()
org_item$clone()The objects of this class are cloneable with this method.
org_item$clone(deep = FALSE)
deepWhether to make a deep clone.
Other class:
citation_meta,
org_list
org_list R6 classA class containing a list of organisations
as_listThe list of org_item objects.
get_default_nameThe organisations default name.
get_default_funderThe default funder.
get_default_publisherThe default publisher.
get_default_rightsholderThe default rightsholder.
get_emailThe organisations email.
get_gitThe git organisation URL.
get_listed_licensesReturn the available licenses.
get_languagesThe different languages of the organisations.
which_funderThe required funders.
which_publisherThe required publishers.
which_rightsholderThe required rightsholders.
org_list$add_item()Add one or more org_item objects to the list.
org_list$add_item(...)
...One or more org_item objects.
org_list$check()Check if the organisation list is compatible with the default as set in the organisations git repository.
org_list$check(x = ".")
xThe path to the project directory
org_list$get_allowed_licenses()Return the allowed licenses.
org_list$get_allowed_licenses(
email = character(0),
type = c("package", "project", "data", "all")
)
emailThe email addresses of the organisations. Returns all available licenses if missing.
typeThe type of license to return.
Can be one of "package", "project", "data" or "all".
org_list$get_person()Return the organisation with matching email as a person().
org_list$get_person(email, role = c("cph", "fnd"), lang)
emailThe email address of the organisation.
roleThe role of the person to return.
langThe language to return the organisation name in.
org_list$get_zenodo_by_email()Return a vector of Zenodo communities associated with the organisations with matching email.
org_list$get_zenodo_by_email(email)
emailThe email addresses to match against.
A character vector with the communities.
org_list$get_match()Return the organisation with a matching name.
org_list$get_match(name)
nameThe name of the organisation to match.
A list with the organisation name, email and match ratio.
org_list$get_name_by_domain()Return the organisation names with a matching email domain.
org_list$get_name_by_domain(email, lang)
emailThe email address to match the domain against.
langThe language to return the organisation name in.
The function extracts the domain from the email address and matches it against the organisation email addresses. If multiple organisations have the same domain, the function returns all matching names. If the language is not available for a specific organisation, it will return the first available name.
A character vector with the organisation names.
org_list$get_pkgdown()get_pkgdown The pkgdown author field
org_list$get_pkgdown(lang)
langThe language to use for affiliation.
org_list$new()Initialize a new org_list object.
org_list$new(..., git = character(0))
...One or more org_item objects.
gitAn optional string with the absolute path to a git
organisation.
E.g. "https://github.com/inbo"
org_list$print()Print the org_list object.
org_list$print()
org_list$read()Read the org_list object from an organisation.yml file.
org_list$read(x = ".")
xThe path to the directory where the organisation.yml file
is stored.
org_list$validate_person()Validate a person object given the org_list object.
org_list$validate_person(person, lang)
personThe person object to validate.
langThe language to use for affiliation.
org_list$validate_rules()Validate the rules for the rightsholder, funder and publisher.
org_list$validate_rules( rightsholder = person(), funder = person(), publisher = person() )
rightsholderThe rightsholders as a person object.
funderThe funders as a person object.
publisherThe publishers as a person object.
org_list$write()Write the org_list object to an organisation.yml file.
org_list$write(x = ".", license = FALSE)
xThe path to the directory where the organisation.yml file
should be written.
licenseWhether to include license information.
The path to the written organisation.yml file.
org_list$clone()The objects of this class are cloneable with this method.
org_list$clone(deep = FALSE)
deepWhether to make a deep clone.
Other class:
citation_meta,
org_item
Get the default organisation list from a git URL This function retrieves the default organisation list from a git URL. It checks if the organisation list is already cached in the user's R configuration. If it is, it returns the cached version. If not, it attempts to retrieve the organisation list from the specified git URL and caches it for future use.
org_list_from_url(git)org_list_from_url(git)
git |
The git URL to retrieve the organisation list from. |
An org_list object containing the organisation list.
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
organisation2df(),
select_license(),
store_organisations(),
stored_organisations()
Results in a data.frame with the email, default name, ROR, ORCID requirement, Zenodo community, website, and logo of the organisation.
organisation2df(x)organisation2df(x)
x |
An |
A data.frame with the organisation information.
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
select_license(),
store_organisations(),
stored_organisations()
Reuse existing individual information or add a new individual. Allows to update existing individual information.
select_individual(email, lang)select_individual(email, lang)
email |
An optional email address. When given and it matches with a single person, the function immediately returns the information of that person. |
lang |
The language to use for the affiliation.
Defaults to the first language in the |
A data.frame with individual information.
Other individual:
add_individual(),
has_person_role(),
individual2badge(),
individual2df(),
individual2person(),
select_person_role(),
store_individuals()
This function allows you to select a license for a project, package or dataset from the list of allowed licenses for the organisation. If there is only one license available, it will be selected automatically.
select_license(org, type = c("package", "project", "data"))select_license(org, type = c("package", "project", "data"))
org |
An object of class |
type |
The type of license to select. One of |
The name of the selected license.
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
organisation2df(),
store_organisations(),
stored_organisations()
Select the person object with a given role
select_person_role(individual, role)select_person_role(individual, role)
individual |
A |
role |
A character vector of roles to check for. |
A logical vector indicating whether the individual has any of the specified roles.
Other individual:
add_individual(),
has_person_role(),
individual2badge(),
individual2df(),
individual2person(),
select_individual(),
store_individuals()
This function converts a git SSH URL to an HTTP URL.
It also removes any OAuth2 tokens from the URL.
The resulting URL is used to determine the root URL of the organisation for
retrieving the organisation list.
ssh_http(url)ssh_http(url)
url |
The git URL to convert. |
The converted HTTP URL.
Other git:
is_repository(),
is_tracked_not_modified()
Store individual details for later usage
store_individuals(x = ".")store_individuals(x = ".")
x |
Path to a project |
Other individual:
add_individual(),
has_person_role(),
individual2badge(),
individual2df(),
individual2person(),
select_individual(),
select_person_role()
This function stores organisation information locally for later retrieval. The organisations are stored in a tab-separated file in the user's data directory.
store_organisations(x)store_organisations(x)
x |
An |
NULL invisibly.
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
organisation2df(),
select_license(),
stored_organisations()
This function retrieves organisation information that was previously stored
using store_organisations().
stored_organisations()stored_organisations()
A data.frame with the stored organisation information.
The data.frame contains the columns: email, default_name, names,
ror, orcid, zenodo, website, and logo.
Returns an empty data.frame if no organisations are stored.
Other organisation:
cache_org(),
get_available_organisations(),
get_default_org_list(),
inbo_org_list(),
new_org_item(),
new_org_list(),
org_list_from_url(),
organisation2df(),
select_license(),
store_organisations()
Validate a citation metadata object
validate_citation(meta)validate_citation(meta)
meta |
A |
A character vector of validation errors, or an empty character vector if the metadata is valid.
Other validation:
validate_email(),
validate_language(),
validate_license_list(),
validate_orcid(),
validate_ror(),
validate_url()
It only checks the format of the text, not if the email address exists.
validate_email(email)validate_email(email)
email |
A vector with email addresses. |
A logical vector.
Other validation:
validate_citation(),
validate_language(),
validate_license_list(),
validate_orcid(),
validate_ror(),
validate_url()
A valid language code is a string in the format of xx-YY, where xx is a
two-letter lowercase language code and YY is a two-letter uppercase
country code.
For example, en-GB for English (United Kingdom) and nl-BE for Dutch
(Belgium).
validate_language(language)validate_language(language)
language |
A string to validate |
The input language code if it is valid, otherwise an error message.
Other validation:
validate_citation(),
validate_email(),
validate_license_list(),
validate_orcid(),
validate_ror(),
validate_url()
Validate a license list
validate_license_list(license)validate_license_list(license)
license |
A list with three named character vectors: |
Invisibly returns NULL if the license list is valid, otherwise
throws an error.
Other validation:
validate_citation(),
validate_email(),
validate_language(),
validate_orcid(),
validate_ror(),
validate_url()
ORCID iD
The ORCID iD is a unique, persistent identifier
free of charge to researchers.
Checks whether the ORCID iD has the proper format and a correct checksum.
The ORCID iD must be in the format 0000-0000-0000-0000 where the last
digit can be a number or "X".
Empty strings are considered valid to allow optional ORCID iD.
validate_orcid(orcid)validate_orcid(orcid)
orcid |
A vector of ORCID |
A logical vector with the same length as the input vector.
Other validation:
validate_citation(),
validate_email(),
validate_language(),
validate_license_list(),
validate_ror(),
validate_url()
The Research Organization Registry (ROR) is a global, community-led registry of open persistent identifiers for research organizations. ROR makes it easy for anyone or any system to disambiguate institution names and connect research organizations to researchers and research outputs. Validate that a ROR is a string of 9 characters starting with 0, followed by 6 characters which can be a letter (except i, l, o) or a digit, and ending with 2 digits.
validate_ror(ror)validate_ror(ror)
ror |
A ROR to validate. |
A logical value indicating whether the ROR is valid.
Other validation:
validate_citation(),
validate_email(),
validate_language(),
validate_license_list(),
validate_orcid(),
validate_url()
Validate that a URL is a string of length 1 which is not NA and matches the pattern of a valid URL.
validate_url(url)validate_url(url)
url |
A URL to validate. |
A logical value indicating whether the URL is valid.
Other validation:
validate_citation(),
validate_email(),
validate_language(),
validate_license_list(),
validate_orcid(),
validate_ror()